@@ -39,6 +39,7 @@ from zope.component import (
     )
 from zope.interface import implements
 from zope.publisher.interfaces import NotFound
+from zope.schema import Field
 from zope.security.proxy import removeSecurityProxy
 from zope.traversing.browser import absoluteURL
 
@@ -403,7 +404,7 @@ class AbstractCollectionFieldMarshaller(SimpleFieldMarshaller):
         super(AbstractCollectionFieldMarshaller, self).__init__(
             field, request)
         self.value_marshaller = getMultiAdapter(
-            (field.value_type, request), IFieldMarshaller)
+            (field.value_type or Field(), request), IFieldMarshaller)
 
     def _marshall_from_json_data(self, value):
         """See `SimpleFieldMarshaller`.
@@ -475,14 +476,15 @@ class DictFieldMarshaller(SimpleFieldMarshaller):
         """See `SimpleFieldMarshaller`.
 
         This also looks for the appropriate marshaller for key_type and
-        value_type.
+        value_type. If key_type or value_type are not specified, the default
+        field marshaller is used.
         """
         super(DictFieldMarshaller, self).__init__(
             field, request)
         self.key_marshaller = getMultiAdapter(
-            (field.key_type, request), IFieldMarshaller)
+            (field.key_type or Field(), request), IFieldMarshaller)
         self.value_marshaller = getMultiAdapter(
-            (field.value_type, request), IFieldMarshaller)
+            (field.value_type or Field(), request), IFieldMarshaller)
 
     def _marshall_from_request(self, value):
         """See `IFieldMarshaller`.
@@ -492,8 +494,8 @@ class DictFieldMarshaller(SimpleFieldMarshaller):
 
         When coming in via HTML request parameters, the dict is sent as a list
         of comma separated "key,value" strings.
-        If the value isn't a list or dict, transform it into a one-element list.
-        That allows web client to submit one-element list of strings
+        If the value isn't a list or dict, transform it into a one-element
+        list. That allows web client to submit one-element list of strings
         without having to JSON-encode it.
         """
         if not isinstance(value, list) and not isinstance(value, dict):
